@@ -21,6 +21,12 @@ import sys
 import nested_diff
 import nested_diff.handlers
 
+HELP_EPILOG = """\
+examples:
+  Print version:
+    %(prog)s --version
+"""
+
 
 class App:
     """Base class for command line tools."""
@@ -49,7 +55,10 @@ class App:
         """
         self.override_excepthook()  # ASAP, but overridable by descendants
 
-        self.argparser = self.get_argparser(description=self.__doc__)
+        self.argparser = self.get_argparser(
+            description=self.__doc__,
+            epilog=getattr(sys.modules[self.__module__], 'HELP_EPILOG', None),
+        )
         self.args = self.argparser.parse_args(args=args)
 
     @staticmethod
@@ -64,7 +73,10 @@ class App:
     @classmethod
     def cli(cls):
         """Cli tool entry point."""
-        return cls().run()
+        try:
+            return cls().run()
+        except KeyboardInterrupt:
+            return 2  # pragma nocover
 
     @property
     def dumper(self):
@@ -79,7 +91,7 @@ class App:
 
             return self.__dumper
 
-    def get_argparser(self, description=None):
+    def get_argparser(self, description=None, epilog=None):
         """Return complete CLI argument parser."""
         return argparse.ArgumentParser(
             description=description,
@@ -87,6 +99,8 @@ class App:
                 self.get_optional_args_parser(),
                 self.get_positional_args_parser(),
             ),
+            formatter_class=argparse.RawDescriptionHelpFormatter,
+            epilog=epilog,
         )
 
     def get_optional_args_parser(self):
@@ -160,17 +174,12 @@ class App:
 
         raise RuntimeError(f'Unsupported output format: {fmt}')
 
-    def guess_fmt(
-        self,
-        fp,
-        default,
-        ignore_fps=(sys.stdin, sys.stdout, sys.stderr),
-    ):
+    def guess_fmt(self, fp, default):
         """Guess format of a file object according it's extension."""
-        if fp in ignore_fps:
-            return default
-
-        fmt = os.path.splitext(fp.name)[-1].split('.')[-1].lower()
+        try:
+            fmt = os.path.splitext(fp.name)[-1].split('.')[-1].lower()
+        except Exception:  # noqa: BLE001
+            fmt = default
 
         if fmt == 'yml':
             fmt = 'yaml'
