@@ -1,4 +1,4 @@
-# Copyright 2019-2024 Michael Samoglyadov
+# Copyright 2019-2026 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,9 +23,27 @@ import nested_diff
 import nested_diff.cli
 import nested_diff.handlers
 
+HELP_EPILOG = """\
+examples:
+  diff two documents:
+    %(prog)s a.json b.yaml
+
+  dIff several documents pairwise:
+    %(prog)s a.json b.json c.json d.json
+
+  show changed elements but omit added and removed:
+    %(prog)s -A=0 -R=0 a.json b.json
+
+  render existing nested diff as HTML page:
+    %(prog)s --show --ofmt=html nd.json
+
+  show changed paths, but not values:
+    %(prog)s --values=none a.json b.json
+"""
+
 
 class App(nested_diff.cli.App):
-    """Diff tool for nested data structures."""
+    """Diff tool for nested structures."""
 
     supported_ofmts = ('auto', 'html', 'json', 'term', 'toml', 'text', 'yaml')
 
@@ -183,8 +201,8 @@ class App(nested_diff.cli.App):
             '-R',
             choices=('0', '1', 'trim'),
             default=1,
-            help='Show removed items; enabled (1) by default. '
-            'Value will be replaced by null when "trim" used',
+            help='show removed items; enabled (1) by default; '
+            'value will be replaced by null when "trim" used',
         )
         parser.add_argument(
             '-U',
@@ -232,7 +250,7 @@ class App(nested_diff.cli.App):
         return super().get_dumper(fmt, **kwargs)
 
     def run(self):
-        """Diff app object entry point."""
+        """Diff app entry point."""
         exit_code = 0
 
         self.args.out.write(self.dumper.header)
