@@ -1,4 +1,4 @@
-# Copyright 2019-2024 Michael Samoglyadov
+# Copyright 2019-2026 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,9 +19,18 @@ import sys
 
 import nested_diff.cli
 
+HELP_EPILOG = """\
+examples:
+  patch document:
+    %(prog)s target.json patch.json
+
+  redefine serialization options:
+    %(prog)s --ofmt json --ofmt-opts '{"indent": null}' target.json patch.json
+"""
+
 
 class App(nested_diff.cli.App):
-    """Patch tool for nested data structures."""
+    """Patch tool for nested structures."""
 
     def get_dumper(self, fmt, **kwargs):
         """Create dumper object according to passed format.
@@ -73,7 +82,7 @@ class App(nested_diff.cli.App):
         return nested_diff.Patcher().patch(target, diff)
 
     def run(self):
-        """Patch app object entry point."""
+        """Patch app entry point."""
         patched = self.patch(
             self.load(self.args.target_file),
             self.load(self.args.patch_file),
